@@ -20,6 +20,7 @@
 #ifndef __CTK_DISPLAYCONFIG_H__
 #define __CTK_DISPLAYCONFIG_H__
 
+
 #include "ctkevent.h"
 #include "ctkconfig.h"
 #include "ctkdisplaylayout.h"
@@ -51,7 +52,8 @@ G_BEGIN_DECLS
 
 typedef enum {
     SELECTABLE_ITEM_SCREEN,
-    SELECTABLE_ITEM_DISPLAY
+    SELECTABLE_ITEM_DISPLAY,
+    SELECTABLE_ITEM_PRIME,
 } SelectableItemType;
 
 
@@ -60,6 +62,7 @@ typedef struct SelectableItemRec {
     union {
         nvDisplayPtr display;
         nvScreenPtr screen;
+        nvPrimeDisplayPtr prime;
     } u;
 } SelectableItem;
 
@@ -96,6 +99,8 @@ typedef struct _CtkDisplayConfig
     GtkWidget *chk_forcecompositionpipeline_enabled;
     GtkWidget *chk_forcefullcompositionpipeline_enabled;
 
+    GtkWidget *chk_force_allow_gsync;
+
     GtkWidget *mnu_selected_item;
     SelectableItem *selected_item_table;
     int selected_item_table_len;
@@ -191,6 +196,16 @@ typedef struct _CtkDisplayConfig
     int *screen_depth_table;
     int screen_depth_table_len;
 
+
+    /* Prime Display - Info */
+    GtkWidget *prime_display_page;
+
+    GtkWidget *lbl_prime_display_view;
+    GtkWidget *lbl_prime_display_name;
+    GtkWidget *lbl_prime_display_sync;
+    GtkWidget *box_prime_display_name;
+
+
     /* Dialogs */
     GtkWidget *dlg_display_disable;
     GtkWidget *txt_display_disable;
