@@ -20,6 +20,7 @@
 #ifndef __CTK_DISPLAYLAYOUT_H__
 #define __CTK_DISPLAYLAYOUT_H__
 
+
 #include "ctkevent.h"
 #include "ctkconfig.h"
 
@@ -227,6 +228,9 @@ typedef struct nvModeRec {
     Bool forceCompositionPipeline;
     Bool forceFullCompositionPipeline;
     Bool allowGSYNC;
+    Bool allowGSYNCCompatibleSpecified;
+    Bool allowGSYNCCompatible;
+    int vrrMinRefreshRate;
 
 } nvMode, *nvModePtr;
 
@@ -251,8 +255,6 @@ typedef struct nvDisplayRec {
     char               *targetIdName;   /* e.g. "DPY-3" */
     char               *randrName;      /* e.g. "VGA-1", "DVI-I-2" */
 
-    Bool                is_sdi;         /* Is an SDI display */
-
     nvModeLinePtr       modelines;      /* Modelines validated by X */
     int                 num_modelines;
 
@@ -303,6 +305,7 @@ typedef struct nvPrimeDisplayRec {
     GdkRectangle rect;
     char *label;
     int screen_num;
+    Bool sync;
 } nvPrimeDisplay, *nvPrimeDisplayPtr;
 
 
@@ -373,15 +376,6 @@ typedef struct nvScreenRec {
 
 
 
-/* GVO Mode information */
-typedef struct GvoModeDataRec {
-    unsigned int id; /* NV-CONTROL ID */
-    char *name;
-    unsigned int rate; /* Refresh rate */
-} GvoModeData;
-
-
-
 /* GPU (Device) */
 typedef struct nvGpuRec {
     struct nvGpuRec *next_in_layout; /* List of all GPUs */
@@ -405,9 +399,6 @@ typedef struct nvGpuRec {
 
     gchar *pci_bus_id;
 
-    GvoModeData *gvo_mode_data; /* Information about GVO modes available */
-    unsigned int num_gvo_modes;
-
     unsigned int *flags_memory; /* Pointer to memory alloced for flags */
     unsigned int *flags; /* Array of flags queried from the X server */
     int num_flags;
